@@ -55,7 +55,9 @@ class TbaasClient(AbstractClient):
 
 
     def BlockByNumberHandler(self, request):
-        """Bcos根据块高查询区块信息
+        """版本升级
+
+        Bcos根据块高查询区块信息
 
         :param request: Request instance for BlockByNumberHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.BlockByNumberHandlerRequest`
@@ -139,7 +141,9 @@ class TbaasClient(AbstractClient):
 
 
     def DeployDynamicContractHandler(self, request):
-        """动态部署合约
+        """版本升级
+
+        动态部署合约
 
         :param request: Request instance for DeployDynamicContractHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.DeployDynamicContractHandlerRequest`
@@ -335,7 +339,9 @@ class TbaasClient(AbstractClient):
 
 
     def GetBlockListHandler(self, request):
-        """Bcos分页查询当前群组下的区块列表
+        """版本升级
+
+        Bcos分页查询当前群组下的区块列表
 
         :param request: Request instance for GetBlockListHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.GetBlockListHandlerRequest`
@@ -643,7 +649,9 @@ class TbaasClient(AbstractClient):
 
 
     def GetTransByHashHandler(self, request):
-        """Bcos根据交易哈希查看交易详细信息
+        """版本升级
+
+        Bcos根据交易哈希查看交易详细信息
 
         :param request: Request instance for GetTransByHashHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.GetTransByHashHandlerRequest`
@@ -671,7 +679,9 @@ class TbaasClient(AbstractClient):
 
 
     def GetTransListHandler(self, request):
-        """Bcos分页查询当前群组的交易信息列表
+        """版本升级
+
+        Bcos分页查询当前群组的交易信息列表
 
         :param request: Request instance for GetTransListHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.GetTransListHandlerRequest`
@@ -839,7 +849,9 @@ class TbaasClient(AbstractClient):
 
 
     def SendTransactionHandler(self, request):
-        """Bcos发送交易
+        """版本升级
+
+        Bcos发送交易
 
         :param request: Request instance for SendTransactionHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.SendTransactionHandlerRequest`
@@ -895,7 +907,9 @@ class TbaasClient(AbstractClient):
 
 
     def TransByDynamicContractHandler(self, request):
-        """根据动态部署的合约发送交易
+        """版本升级
+
+        根据动态部署的合约发送交易
 
         :param request: Request instance for TransByDynamicContractHandler.
         :type request: :class:`tencentcloud.tbaas.v20180416.models.TransByDynamicContractHandlerRequest`
